# Howto regenerate typesupport

The cyclonedds.idl._typesupport module is generated by normal idlc usage:

$ idlc -l py -p py-root-prefix=cyclonedds.idl._typesupport ddsi_xt_type_object.idl
$ idlc -l py -p py-root-prefix=cyclonedds.idl._typesupport ddsi_xt_typemap.idl

After generating, the type `StronglyConnectedComponentId` in the generated
file `DDS/XTypes/_ddsi_xt_type_object.py` needs an unsafe-hash flag:

`@dataclass(unsafe_hash=True)`
